OCR Engine
Provides complete OCR pipeline encapsulation, performs detection and recognition in one call
Structs
- DetOnly
Engine - Detection-only engine
- OcrEngine
- OCR engine
- OcrEngine
Builder - Builder for OCR engine
- OcrEngine
Config - OCR engine configuration
- OcrResult_
- OCR result
- RecOnly
Engine - Recognition-only engine
- Recognize
Options - Per-call recognition options.
Enums
- Rotated
Text Mode - Strategy for recognizing text whose baseline is rotated by 90 or 270 degrees.
Functions
- ocr_
file - Convenience function: recognize from file
- ocr_
file_ with_ ori - Convenience function: recognize from file with orientation model