pub fn nms(boxes: &[TextBox], iou_threshold: f32) -> Vec<TextBox>Expand description
Non-Maximum Suppression (NMS)
Filter overlapping bounding boxes, keep ones with highest scores Also filters small boxes that are largely contained within other boxes
Parameters
boxes: List of bounding boxesiou_threshold: IoU threshold, boxes exceeding this value are considered overlapping