OcrEngineConfig

Struct OcrEngineConfig 

pub struct OcrEngineConfig {
    pub backend: Backend,
    pub thread_count: i32,
    pub precision_mode: PrecisionMode,
    pub det_options: DetOptions,
    pub rec_options: RecOptions,
    pub ori_options: OriOptions,
    pub enable_parallel: bool,
    pub min_result_confidence: f32,
    pub ori_min_confidence: f32,
}
OCR engine configuration

Fields

backend: Backend

Inference backend

thread_count: i32

Thread count

precision_mode: PrecisionMode

Precision mode

det_options: DetOptions

Detection options

rec_options: RecOptions

Recognition options

ori_options: OriOptions

Orientation options (used when orientation model is enabled)

enable_parallel: bool

Whether to enable parallel recognition (use rayon to process multiple text regions in parallel)

min_result_confidence: f32

Minimum confidence threshold at result level (recognition results below this value will be filtered)

ori_min_confidence: f32

Minimum confidence threshold for orientation correction

Implementations

Source

impl OcrEngineConfig

pub fn new() -> Self

Create new configuration

pub fn with_backend(self, backend: Backend) -> Self

Set inference backend

pub fn with_threads(self, threads: i32) -> Self

Set thread count

pub fn with_precision(self, precision: PrecisionMode) -> Self

Set precision mode

pub fn with_det_options(self, options: DetOptions) -> Self

Set detection options

pub fn with_rec_options(self, options: RecOptions) -> Self

Set recognition options

pub fn with_ori_options(self, options: OriOptions) -> Self

Set orientation options

pub fn with_parallel(self, enable: bool) -> Self

Enable/disable parallel processing

Note: When multiple text regions are detected, use rayon for parallel recognition. If MNN is already set to multi-threading, enabling this option may cause thread contention.

pub fn with_min_result_confidence(self, threshold: f32) -> Self

Set minimum confidence threshold at result level

Recognition results below this threshold will be filtered out. Recommended values: 0.5 (lenient), 0.7 (balanced), 0.9 (strict)

pub fn with_ori_min_confidence(self, threshold: f32) -> Self

Set minimum confidence threshold for orientation correction

pub fn fast() -> Self

Fast mode preset

pub fn gpu() -> Self

GPU mode preset (OpenCL)